@@ -29,7 +29,7 @@ def load_FIRe_files(file_, append=False, save_files=False, res_path=None, seq_le
     flen : float, default=1e-6
         The flashlet length in seconds. 
     irrad : int, default=None                 
-        The LED output in μE m\ :sup:`2` s\ :sup:`-1`. Only required if continuous = True.
+        The LED output in μE m\ :sup:`2` s\ :sup:`-1`.
     continuous : bool, default=False
         If True, will load files from the continuous format. If False, will load the discrete file format.
     light_step: bool, default=False
@@ -390,7 +390,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
 
     if FastAct1:
         if Single_Acq:
-            md = read_csv(file_, delimiter=delimiter, skiprows=11, nrows=6, usecols=[0,1], header=None)
+            md = read_csv(file_, delimiter=delimiter, skiprows=11, nrows=6, usecols=[0,1], header=None, encoding='latin1')
             datetime = to_datetime(str(md.iloc[4,1])+' '+str(md.iloc[5,1]))
             led = md.iloc[0:3,1].astype(float)
             led = led.isnull()
@@ -413,7 +413,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
             led2 = array(float(md.iloc[1,1]))
             led3 = array(float(md.iloc[2,1]))
             led = nansum([led1, led2, led3])
-            df = read_csv(file_, delimiter=delimiter, skiprows = 21, nrows=seq_len, header=None).drop(columns=[2,3])
+            df = read_csv(file_, delimiter=delimiter, skiprows = 21, nrows=seq_len, header=None, encoding='latin1').drop(columns=[2,3])
             flashlet_number = df.iloc[:,1]
             seq_time = df.iloc[:,0]
             seq_reps = df.iloc[:,2:].shape[1]
@@ -427,7 +427,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
             df = DataFrame([flashlet_number.values, df.values, datetime.values, seq.values, seq_time.values, pfd.values, led_sequence]).T
             df.columns = ['flashlet_number','flevel','datetime','seq','seq_time','pfd','led_sequence']
         else:
-            md = read_csv(file_, skiprows=16, nrows=12, header=None, delimiter=delimiter)
+            md = read_csv(file_, skiprows=16, nrows=12, header=None, delimiter=delimiter, encoding='latin1')
             md = md.T.iloc[2:,:]
             md.columns = ['seq', 'led450', 'led530', 'led624', 'PMT', 'a', 'pitch', 'reps', 'int', 'b', 'date', 'time']
             md = md.drop(['a','b'],axis=1).reset_index(drop=True)
@@ -453,7 +453,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
                 elif (led.iloc[i,2] == False) & (led.iloc[i,0] == True) & (led.iloc[i,1] == True): # LED 3 only
                     led_idx.append(7)
             
-            df = read_csv(file_, skiprows=43, nrows=seq_len, header=None, delimiter=delimiter)
+            df = read_csv(file_, skiprows=43, nrows=seq_len, header=None, delimiter=delimiter, encoding='latin1')
             seq_time = df.iloc[:,0]
             flashlet_number = df.iloc[:,1]
             df = df.iloc[:,2:]
@@ -474,7 +474,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
     
     else:
         if Single_Acq:
-            df = read_csv(file_, skiprows=2, nrows=18, usecols=[0,1], header=None)
+            df = read_csv(file_, skiprows=2, nrows=18, usecols=[0,1], header=None, encoding='latin1')
             date = df.iloc[0,1]
             time = df.iloc[1,1]
             datetime = repeat(to_datetime(date+' '+time, dayfirst=True), seq_len * 4 * seq_reps)
@@ -483,7 +483,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
             led1 = Series(repeat(((float(df.iloc[13,1]) * 1e22) * flen * sigscale), seq_len))
             led2 = Series(repeat(((float(df.iloc[14,1]) * 1e22) * flen * sigscale), seq_len))
             led3 = Series(repeat(((float(df.iloc[15,1]) * 1e22) * flen * sigscale), seq_len))
-            df = read_csv(file_, skiprows=41, nrows=seq_len, header=None)
+            df = read_csv(file_, skiprows=41, nrows=seq_len, header=None, encoding='latin1')
             seq_time = concat([df.iloc[:,1]]*4*seq_reps).reset_index(drop=True)
             df1 = Series(reshape(df.iloc[:,3:(seq_reps+3)].values.T, [-1]))
             df2 = Series(reshape(df.iloc[:,(seq_reps+6):((seq_reps+3)*2)].values.T, [-1]))
@@ -495,7 +495,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
             df.columns = ['flashlet_number','flevel','datetime','seq_time','pfd','led_sequence']
         
         else:
-            df = read_csv(file_, skiprows=2, nrows=16, usecols=[0,1], header=None)
+            df = read_csv(file_, skiprows=2, nrows=16, usecols=[0,1], header=None, encoding='latin1')
             date = df.iloc[0,1]
             time = df.iloc[1,1]
             datetime = repeat(to_datetime(date+' '+time, dayfirst=True), seq_len * 4 * seq_reps)
@@ -504,7 +504,7 @@ def load_FastOcean_files(file_, append=False, save_files=False, led_separate=Fal
             led1 = Series(repeat(((float(df.iloc[13,1]) * 1e22) * flen * sigscale), seq_len))
             led2 = Series(repeat(((float(df.iloc[14,1]) * 1e22) * flen * sigscale), seq_len))
             led3 = Series(repeat(((float(df.iloc[15,1]) * 1e22) * flen * sigscale), seq_len))
-            df = read_csv(file_, skiprows=46, nrows=seq_len, header=None)
+            df = read_csv(file_, skiprows=46, nrows=seq_len, header=None, encoding='latin1')
             seq_time = concat([df.iloc[:,0]] * (4 * seq_reps))
             df1 = Series(reshape(df.iloc[:,2:2+seq_reps].values.T, [-1]))
             df = read_csv(file_, skiprows=212, nrows=seq_len, header=None)
